@@ -7,7 +7,7 @@ from django.utils.encoding import python_2_unicode_compatible
 class Book(models.Model):
     isbn = models.CharField(max_length=50, unique=True)
     title = models.CharField(max_length=100)
-    author = models.ForeignKey(settings.AUTH_USER_MODEL)
+    author = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
 
     def __str__(self):
         return self.title
